package Qt::Network::QTcpSocket;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QTcpSocket
# file     : QtNetwork/qtcpsocket.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Network::QAbstractSocket/;
#our @ISA = qw/Qt::Network::QAbstractSocket/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Network::QTcpSocket

=head1 PUBLIC METHODS

=over

=item   QTcpSocket(QObject * parent)

=item   QTcpSocket(QObject * parent = 0)

=item   ~QTcpSocket()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
